==> pytech_rules-0.1.0-py3-none-any.whl: pytech/rules/rules.py <==
from dataclasses import dataclass
from pytech.rules.conversions import no_conversion

__all__ = [
    "apply_rules",
    "Rule",
    "validate_rules",
]


@dataclass(frozen=True)
class Rule:
    """
    Rule type dataclass

    fields -> the list of fields to use for the conversion
    convert -> a callable to use to compute the value
    cast_to -> a type to use for the converted casting
    """
    fields: []
    cast_to: type
    convert: callable = no_conversion


def validate_rules(rules: {any: Rule}):
    """
    Check if given rules are valid.
    If the check fails it raises an error, otherwise no action is performed.

    :param rules: a dict of Rules
    :raises: TypeError, ValueError
    """

    if not isinstance(rules, dict):
        raise TypeError("Rules must be a dict.")

    if not all(isinstance(el, Rule) for el in rules.values()):
        raise TypeError("Every rule value must be a Rule.")

    if not all(isinstance(el.fields, list | tuple) for el in rules.values()):
        raise TypeError("Every rule fields value must be a list (or tuple).")

    if not all(isinstance(el.cast_to, type) for el in rules.values()):
        raise TypeError("Every rule cast_to value must be a class.")

    if not all(len(el.fields) for el in rules.values()):
        raise ValueError("Rule fields must be a non empty list.")

    if not all(callable(el.convert) for el in rules.values()):
        raise ValueError("Rule convert must be a callable.")


def apply_rules(rules: {any: Rule}, data: {any: any}) -> dict:
    """
    Validates the provided rules.
    If the check passes the rules are applied to the data to create a new dict.

    :param rules: a dict of Rules
    :param data: the dict of data to convert
    :return: the dict data created applying the rules
    """
    validate_rules(rules)

    return {
        k: rule.cast_to(rule.convert(*(data[key] for key in rule.fields)))
        for k, rule in rules.items()
    }

==> pytech_rules-2.0.1-py3-none-any.whl: pytech/rules/rules.py <==
from dataclasses import dataclass
from typing import List, Callable, Any, Dict

from pytech.rules.conversions import no_conversion

__all__ = [
    "apply_rules",
    "Rule",
    "validate_rules",
]


@dataclass(frozen=True)
class Rule:
    """
    Rule type dataclass

    fields -> the list of fields to use for the conversion
    convert -> a callable to use to compute the value
    """
    fields: List
    convert: Callable = no_conversion


def validate_rules(rules: Dict[Any, Rule]) -> None:
    """
    Check if given rules are valid.
    If the check fails it raises an error, otherwise no action is performed.

    :param rules: a dict of Rules
    :raises: TypeError, ValueError
    """

    if not isinstance(rules, dict):
        raise TypeError("Rules must be a dict.")

    if not all(isinstance(el, Rule) for el in rules.values()):
        raise TypeError("Every rule value must be a Rule.")

    if not all(isinstance(el.fields, list | tuple) for el in rules.values()):
        raise TypeError("Every rule fields value must be a list (or tuple).")

    if not all(len(el.fields) for el in rules.values()):
        raise ValueError("Rule fields must be a non empty list.")

    if not all(callable(el.convert) for el in rules.values()):
        raise ValueError("Rule convert must be a callable.")


def apply_rules(rules: Dict[Any, Rule], data: Dict[Any, Any]) -> Dict:
    """
    Validates the provided rules.
    If the check passes the rules are applied to the data to create a new dict.

    :param rules: a dict of Rules
    :param data: the dict of data to convert
    :return: the dict data created applying the rules
    """
    validate_rules(rules)

    return {
        k: rule.convert(*(data[key] for key in rule.fields))
        for k, rule in rules.items()
    }
